sql

package
v0.0.0-...-3f8b912 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 15, 2019 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func And

func And(conditions ...stmt.Condition) *stmt.ConditionList

And ...

func Column

func Column(name string) *stmt.Column

Column ...

func Count

func Count(expr stmt.Expression) *stmt.Function

Count ...

func Function

func Function(name string, args ...stmt.Expression) *stmt.Function

Function ... TODO: We can shortcut a ton of common functions, and make it easier to not mess them up too by making functions for many of them. May be best to be in another package though?

func Int

func Int(val int) *stmt.Int

Int ...

func Join

func Join(joinType token.JoinType, fromItem stmt.FromItem) *stmt.Join

Join ...

func Null

func Null() *stmt.Null

Null ...

func Or

func Or(conditions ...stmt.Condition) *stmt.ConditionList

Or ...

func Schema

func Schema(name string) *stmt.Schema

Schema ...

func Select

func Select(selectExpressions ...stmt.SelectExpression) *stmt.Select

SelectBuilder ...

func String

func String(val string) *stmt.String

String ...

func Table

func Table(name string) *stmt.Table

Table ...

Types

This section is empty.

Directories

Path Synopsis

Jump to