builder

package
v0.0.0-...-3f8b912 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 15, 2019 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Context

type Context struct {
	// contains filtered or unexported fields
}

Context is a type that handles the state related to how a query is built; for example, controlling the parameters used for the dialect of SQL being used.

func NewContext

func NewContext() *Context

NewContext returns a new Context instance.

func (*Context) AddArgs

func (c *Context) AddArgs(args ...interface{})

AddArgs ...

func (*Context) Args

func (c *Context) Args() []interface{}

Args ...

func (*Context) Depth

func (c *Context) Depth(n int) int

Depth ..

func (*Context) Indent

func (c *Context) Indent() string

Indent ...

func (*Context) String

func (c *Context) String() string

String ...

func (*Context) Write

func (c *Context) Write(s string)

Write ...

Jump to