Documentation
¶
Index ¶
- func And(conditions ...stmt.Condition) *stmt.ConditionList
- func Column(name string) *stmt.Column
- func Count(expr stmt.Expression) *stmt.Function
- func Function(name string, args ...stmt.Expression) *stmt.Function
- func Int(val int) *stmt.Int
- func Join(joinType token.JoinType, fromItem stmt.FromItem) *stmt.Join
- func Null() *stmt.Null
- func Or(conditions ...stmt.Condition) *stmt.ConditionList
- func Schema(name string) *stmt.Schema
- func Select(selectExpressions ...stmt.SelectExpression) *stmt.Select
- func String(val string) *stmt.String
- func Table(name string) *stmt.Table
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Function ¶
func Function(name string, args ...stmt.Expression) *stmt.Function
Function ... TODO: We can shortcut a ton of common functions, and make it easier to not mess them up too by making functions for many of them. May be best to be in another package though?
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.